@@ -17,6 +17,8 @@ from starlette.staticfiles import StaticFiles
 
 from fastapi import FastAPI, Form, Depends, File, UploadFile, Body
 
+app_ = FastAPI(title='AppZoo')  # todo: 全局变量
+
 
 class App(object):
     """
@@ -26,11 +28,13 @@ class App(object):
     app.add_route()
 
     if __name__ == '__main__':
-        app.run(f"{app.app_file_name(__file__)}:app_", port=9955, debug=True)
+        app.run(app.app_from(__file__), port=9955, debug=True)
     """
 
     def __init__(self, verbose=True):
-        self.app = FastAPI()
+        # self.app = FastAPI()
+        self.app = app_
+
         self.verbose = verbose  # 是否返回请求体
 
         # 原生接口
@@ -60,8 +64,8 @@ class App(object):
         uvicorn.config.LOGGING_CONFIG['formatters']['access'][
             'fmt'] = '%(asctime)s - %(levelprefix)s %(client_addr)s - "%(request_line)s" %(status_code)s'
 
-        if debug == False:
-            access_log = False
+        # if debug == False:
+        #     access_log = False
 
         uvicorn.run(
             app if app else self.app,
@@ -73,16 +77,27 @@ class App(object):
         handler = self._handler(func, method, **kwargs)
         self.app.api_route(path=path, methods=[method])(handler)
 
-    def add_apps(self, app_dir='apps', **kwargs):
-        """加载当前app_dir文件夹下的所有app, 入口函数都是main"""
+    def add_apps(self, app_dir='apps', prefix='/', **kwargs):
+        """加载当前app_dir文件夹下的所有app（递归）, 入口函数都是main
+        1. 过滤掉 _ 开头的py文件
+        2. 支持单文件
+        """
         routes = []
-        for p in Path(app_dir).rglob('*.py'):
-            if not p.stem.startswith('_'):  # 过滤_开头的py
-                route = '/' + str(p)[:-3]
-                func = importlib.import_module(route.strip('/').replace('/', '.')).main
-                self.add_route(route, func, method='POST', **kwargs)
+        if Path(app_dir).is_dir():
+            for p in Path(app_dir).rglob('*.py'):
+                if not p.stem.startswith('_'):  # 过滤_开头的py
+                    route = '/' + str(p)[:-3]
+                    routes.append(route)
 
-                routes.append(route)
+                    func = importlib.import_module(route.strip('/').replace('/', '.')).main
+                    self.add_route(f"{Path(prefix) / Path(route)}", func, method='POST', **kwargs)
+
+        else:
+            route = app_dir = Path(app_dir).stem
+            routes.append(app_dir)
+
+            func = importlib.import_module(route).main
+            self.add_route(f"{Path(prefix) / Path(route)}", func, method='POST', **kwargs)
 
         logger.info(f"Add Routes: {routes}")
 
