@@ -9,5 +9,5 @@
 # @Description  : 
 
 
-from .App import App
-from .RpcApp import RpcApp
\ No newline at end of file
+from .App import App, app_
+from .RpcApp import RpcApp
